`sgqlc.types` module
====================

.. automodule:: sgqlc.types
    :members: Schema, Scalar, Enum, Union, Variable, Arg, ArgDict, Field, Type, Interface, Input, Int, Float, String, Boolean, ID, non_null, list_of, BaseType, BaseMeta, BaseItem, ContainerType, ContainerTypeMeta
    :special-members:
    :show-inheritance:
    :private-members:

Sub Modules
-----------

* :doc:`sgqlc.types.datetime`
* :doc:`sgqlc.types.relay`
